@@ -54,13 +54,16 @@ function tw_version
 
 function tw_twd
 {
-	if [[ -f "$1" ]]
+	TW_DICTIONARY="$1"
+	TW_TERM="$2"
+	if [[ -f "$TW_DICTIONARY" ]]
 	then
-		TW_TERM=$(sed -e 's,(,\\(,g' -e 's,),\\),g' <<< "$2")
-		gawk -F" : " '$1 ~ /'"$TW_TERM"'/' "$1"
+		TW_PMATCH=$(grep -iw "$TW_TERM" "$TW_DICTIONARY")
+		if grep -qiw "$TW_TERM" <(gawk -F" : " '{ print $1 }' <<< "$TW_PMATCH")
+		then echo "$TW_PMATCH"
+		fi
 		exit 0
 	else
-		TW_DICTIONARY="$1"
 		tw_error "$TW_DICTIONARY: file not found"
 	fi
 }
@@ -89,9 +92,7 @@ function tw_freetranslation
 #		"en-zt") TW_LANGUAGE="English/TraditionalChinese";;
 	esac
 	TW_TERM=$(iconv -f "UTF-8" -t "ISO-8859-15" <<< "$2")
-	curl -s -d "srctext=${TW_TERM}" -d "language=${TW_LANGUAGE}" \
-	-d "sequence=core" http://ets.freetranslation.com | \
-	iconv -f "ISO-8859-15" -t "UTF-8"
+	curl -s -d "srctext=${TW_TERM}" -d "language=${TW_LANGUAGE}" -d "sequence=core" http://ets.freetranslation.com | iconv -f "ISO-8859-15" -t "UTF-8"
 	printf "\n"
 }
 
@@ -121,16 +122,14 @@ function tw_ls_dictionaries_freetranslation
 function tw_google_language_tools
 {
 	case "${1##*.}" in
-		"zh_zt") TW_LANGUAGE="zh-CN|zh-TW";;
-		"zt_zh") TW_LANGUAGE="zh_TW|zh-CN";;
-		"en_zh") TW_LANGUAGE="en|zh-CN";;
-		"en_zt") TW_LANGUAGE="en|zh_TW";;
+		"zh-zt") TW_LANGUAGE="zh-CN|zh-TW";;
+		"zt-zh") TW_LANGUAGE="zh_TW|zh-CN";;
+		"en-zh") TW_LANGUAGE="en|zh-CN";;
+		"en-zt") TW_LANGUAGE="en|zh_TW";;
 		*) TW_LANGUAGE=$(printf ${1##*.} | tr '-' '|');;
 	esac
 	TW_TERM="$2"
-	curl -s -A "Mozilla/5.0" -d "hl=en" -d "ie=UTF8" -d "text=${TW_TERM}" \
-	-d "langpair=${TW_LANGUAGE}" http://translate.google.com/translate_t | \
-	grep "gtrans" | gawk -F"gtrans" '{print $2}' | cut -d'"' -f2
+	curl -s -A "Mozilla/5.0" -d "hl=en" -d "ie=UTF8" -d "text=${TW_TERM}" -d "langpair=${TW_LANGUAGE}" http://translate.google.com/translate_t | grep "gtrans" | gawk -F"gtrans" '{print $2}' | cut -d'"' -f2
 }
 
 function tw_ls_dictionaries_google_language_tools
@@ -173,8 +172,7 @@ function tw_ls_dictionaries
  	exit 0
 }
 
-TEMP=$(getopt -o "lhv" \
-	-l "list,help,version" -n "$TW" -- "$@")
+TEMP=$(getopt -o "lhv" -l "list,help,version" -n "$TW" -- "$@")
 eval set -- "$TEMP"
 while [[ ! -z "$1" ]]
 do
